function Feuerbach

% http://geometrie.hs-nb.de/MATLAB-Programme/Feuerbach.m   Bearbeitungsstand: 26.4.2004
% (C) Martin Nitschke, nitschke@hs-nb.de

clc;
close('all')
global ax
ax=[inf -inf inf -inf];
deg=pi/180;
phi=[0:360]*deg;

A=[0;0];
c=[50;0];
b=[10;23];

B=A+c;
C=A+b;
Polygon([A B C A],'k','linewidth',2.0);
hold('on');
Polygon([Hoehenfusspunkt(A,B,C) C],'k');
Polygon([Hoehenfusspunkt(B,C,A) A],'k');
Polygon([Hoehenfusspunkt(C,A,B) B],'k');
H=SchnittGerGer(A,Hoehenfusspunkt(B,C,A),B,Hoehenfusspunkt(C,A,B));
Polygon(H,'ok','Markersize',15);
Polygon([Hoehenfusspunkt(A,B,C) Hoehenfusspunkt(B,C,A) Hoehenfusspunkt(C,A,B)],'ok','Markersize',15,'MarkerFaceColor','k');
Polygon([H+A H+B H+C]/2,'sk','Markersize',15,'MarkerFaceColor','k');
Polygon([A+B B+C C+A]/2,'dk','Markersize',15,'MarkerFaceColor','k');
M1=(A+2*B+C)/4;
v1=C-A;
M2=(B+2*C+A)/4;
v2=A-B;
MF=SchnittGerGer(M1,M1+[-v1(2);v1(1)],M2,M2+[-v2(2);v2(1)]);
rF=norm(MF-(A+B)/2);
Polygon(repmat(MF,size(phi))+rF*[cos(phi);sin(phi)],'k','linewidth',1.0)
P=[Hoehenfusspunkt(A,B,C) Hoehenfusspunkt(B,C,A) Hoehenfusspunkt(C,A,B) [H+A H+B H+C A+B B+C C+A]/2];
t=cart2pol(P(1,:)-repmat(MF(1,:),1,9),P(2,:)-repmat(MF(2,:),1,9));
[t,I]=sort(t)
P=P(:,I);
Polygon([P P(:,1)],'k')
PM=(P+P(:,[2:end 1]))/2;
for k=1:9
  Polygon([PM(:,k) MF+0.2*(MF-PM(:,k))],'k','linewidth',0.25)
end
hold('off')
axis('equal')
axis(ax)
axis('off')
print('-deps','Feuerbach');

function H=Hoehenfusspunkt(A,B,C);
syms('t','real');
v=B-A;
H=A+double(solve(v'*(A+t*v-C),t))*(B-A);

function S=SchnittGerGer(A,B,C,D)
syms('t','real');
n=[C(2)-D(2);D(1)-C(1)];
S=A+double(solve(n'*(A+t*(B-A)-C),t))*(B-A);

function Polygon(P,varargin);
global ax
plot(P(1,:),P(2,:),varargin{:})
if min(P(1,:))<ax(1)
  ax(1)=min(P(1,:));
end
if max(P(1,:))>ax(2)
  ax(2)=max(P(1,:));
end
if min(P(2,:))<ax(3)
  ax(3)=min(P(2,:));
end
if max(P(2,:))>ax(4)
  ax(4)=max(P(2,:));
end