function GrosskreisbogenAB

% http://geometrie.hs-nb.de/MATLAB-Programme/GrosskreisbogenAB.m   Bearbeitungsstand: 29.9.2004
% (C) Martin Nitschke, nitschke@hs-nb.de

% Ausserdem bentigt: Terrainbase 5-Minute Global Digital Elevation Model (tbase.bin)
%                     des National Geophysical Data Center (NGDC)
%                     http://www.ngdc.noaa.gov/mgg/gravity/1999/data/global/tbase/

deg=pi/180;

% Datengitter  1/12
% Quelle: http://www.ngdc.noaa.gov/mgg/gravity/1999/data/global/tbase/

id=fopen('tbase.bin','r');
A=fread(id,[4320 2160],'int16=>int16')';
fclose(id);
A=A(end:-1:1,:);
hS=2810;                   % Hhe Sdpol
n=4;
d=n/12;                    % Vergrberung des Gitters auf n/12
A=A(n:n:end,1:n:end);
H=double([repmat(hS,1,size(A,2)+1); A A(:,1)]);
clear A 
close('all') 
[L,B]=meshgrid([-180:d:180]*deg,[-90:d:90]*deg);
[X,Y,Z]=sph2cart(L,B,1); 
surf(X,Y,Z,H); 
hold('on') 
axis('equal') 
colormap(topocolors(min(min(H)),max(max(H)))) 
shading('interp')
caxis([min(min(H)) max(max(H))])
dms2rad=inline('(d+m/60+s/3600)*pi/180','d','m','s');
lambdaA=dms2rad( 13,15,43); phiA=dms2rad(53,33,22); % A=NB
lambdaB=dms2rad(139,32,22); phiB=dms2rad(35,40,21); % B=Tokio
[xA,yA,zA]=sph2cart(lambdaA,phiA,1);
[xB,yB,zB]=sph2cart(lambdaB,phiB,1);
e1S=[xA;yA;zA];
e3S=cross([xA;yA;zA],[xB;yB;zB]);
e3S=e3S/norm(e3S);
e2S=cross(e3S,e1S);
R=[e1S e2S e3S];
plot3([0 1],[0 0],[0 0],'color',0.5*[1 1 1],'erase','none')
plot3([0 0],[0 1],[0 0],'color',0.5*[1 1 1],'erase','none')
plot3([0 0],[0 0],[0 1],'color',0.5*[1 1 1],'erase','none')
Spitze([1;0;0],[1;0;0],0.1,30*deg,'color',0.5*[1 1 1],'erase','none')
Spitze([0;1;0],[0;1;0],0.1,30*deg,'color',0.5*[1 1 1],'erase','none')
Spitze([0;0;1],[0;0;1],0.1,30*deg,'color',0.5*[1 1 1],'erase','none')
Schrift([1;0;0],'{\bf\ite}_1','color',0.5*[1 1 1],'erase','none','HorizontalAlignment','right','VerticalAlignment','middle')
Schrift([0;1;0],'_{ }{\bf\ite}_2','color',0.5*[1 1 1],'erase','none','HorizontalAlignment','left','VerticalAlignment','middle')
Schrift([0;0;1],'{\bf\ite}_{3 }','color',0.5*[1 1 1],'erase','none','HorizontalAlignment','right','VerticalAlignment','middle')
plot3([0 e1S(1)],[0 e1S(2)],[0 e1S(3)],'k','erase','none')
plot3([0 e2S(1)],[0 e2S(2)],[0 e2S(3)],'k','erase','none')
plot3([0 e3S(1)],[0 e3S(2)],[0 e3S(3)],'k','erase','none')
plot3([0 xB],[0 yB],[0 zB],'--k','erase','none')
Schrift([0;0;0],'\itO','erase','none','HorizontalAlignment','center','VerticalAlignment','top')
Schrift(e1S/2,'{\bf\ite}_1''=_{ }{\bf\ita}_{ }','erase','none','HorizontalAlignment','right','VerticalAlignment','middle')
Schrift(e1S,'\itA','erase','none','HorizontalAlignment','right','VerticalAlignment','bottom')
Schrift(e2S/2+[0;0;0.05],'{\bf\ite}_2''','erase','none','HorizontalAlignment','left','VerticalAlignment','top')
Schrift([xB;yB;zB],'{\itB}','erase','none','HorizontalAlignment','left','VerticalAlignment','bottom')
Schrift(e3S,'_{ }{\bf\ite}_3''','erase','none','HorizontalAlignment','left','VerticalAlignment','middle')
Schrift([xB;yB;,zB]/2,'{\bf\itb}','erase','none','HorizontalAlignment','left','VerticalAlignment','bottom')
Spitze(e1S,e1S,0.1,30*deg,'k','erase','none')
Spitze(e2S,e2S,0.1,30*deg,'k','erase','none')
Spitze(e3S,e3S,0.1,30*deg,'k','erase','none')
Spitze([xB;yB;zB],[xB;yB;zB],0.1,30*deg,'k','erase','none')
dS=acos(dot(e1S,[xB;yB;zB]));
t=linspace(0,dS,round(dS/deg));
Z=R*[cos(t);sin(t);zeros(size(t))];
plot3(Z(1,:),Z(2,:),Z(3,:),'k','linewidth',2.0,'erase','none')
t=linspace(dS,2*pi,360-round(dS/deg));
Z=R*[cos(t);sin(t);zeros(size(t))];
plot3(Z(1,:),Z(2,:),Z(3,:),'k','erase','none')
t=[0:360]*deg;
plot3(cos(t),sin(t),zeros(size(t)),'color',0.5*[1 1 1],'erase','none')
view(155,14)
axis([-0.7 0.8 -0.7 0.9 0 0.8])
axis('off') 
print('-depsc','GrosskreisbogenAB')

% Hilfsfunktionen zur Farbgestaltung

function C=topocolors(a,b)
% schwarz-weiss
q=0.3;
C=[q*gray(-a)+(1-q)*ones(-a,3)
  q*gray(b)+(1-q)*ones(b,3)];
% % Farbe
% C=[topomaptrans(1:36,1:-a)
%   topomaptrans(37:64,1:b)];
% % aufhellen
% a=0.3;
% C=a*C+(1-a)*ones(size(C));

function T=topomaptrans(I,J)
if isempty(J)
  T=[];
else
  load('topo','topomap1')
  K=polyval( polyfit(J([1 end]),I([1 end]),1) , J);
  T=[topomap1(I(1),:)
    interp1(I,topomap1(I,:),K(2:end-1))
    topomap1(I(end),:)];
end

function Schrift(P,txt,varargin)
text(P(1),P(2),P(3),txt,'FontName','TimesNewRoman','FontSize',36,varargin{:});

function Spitze(P,v,L,lambda,varargin);
deg=pi/180;
if nargin<=2
  L=1;
end
if nargin<=3
  lambda=7.5*deg;
end
v=L*v./repmat(sqrt(dot(v,v)),size(P,1),1);
Q=P-v;
t=[0:6:360]*deg;
for k=1:size(P,2)
  N=tan(lambda/2)*null(v(:,k)');
  for w=2:length(t)
    plot3(...
      [P(1,k) Q(1,k)+cos(t(w))*L(:,k)*N(1,1)+sin(t(w))*L(:,k)*N(1,2) Q(1,k)+cos(t(w-1))*L(:,k)*N(1,1)+sin(t(w-1))*L(:,k)*N(1,2) P(1,k)],...
      [P(2,k) Q(2,k)+cos(t(w))*L(:,k)*N(2,1)+sin(t(w))*L(:,k)*N(2,2) Q(2,k)+cos(t(w-1))*L(:,k)*N(2,1)+sin(t(w-1))*L(:,k)*N(2,2) P(2,k)],...
      [P(3,k) Q(3,k)+cos(t(w))*L(:,k)*N(3,1)+sin(t(w))*L(:,k)*N(3,2) Q(3,k)+cos(t(w-1))*L(:,k)*N(3,1)+sin(t(w-1))*L(:,k)*N(3,2) P(3,k)],...
      varargin{:});
    end
  end
