function Kugeldreieck3R

% http://geometrie.hs-nb.de/MATLAB-Programme/Kugeldreieck3R.m   Bearbeitungsstand: 4.10.2004
% (C) Martin Nitschke, nitschke@hs-nb.de

% Ausserdem bentigt: Terrainbase 5-Minute Global Digital Elevation Model (tbase.bin)
%                     des National Geophysical Data Center (NGDC)
%                     http://www.ngdc.noaa.gov/mgg/gravity/1999/data/global/tbase/

deg=pi/180;

% Datengitter  1/12
% Quelle: http://www.ngdc.noaa.gov/mgg/gravity/1999/data/global/tbase/

id=fopen('tbase.bin','r');
A=fread(id,[4320 2160],'int16=>int16')';
fclose(id);
A=A(end:-1:1,:);
hS=2810;                   % Hhe Sdpol
n=4;
d=n/12;                    % Vergrberung des Gitters auf n/12
A=A(n:n:end,1:n:end);
H=double([repmat(hS,1,size(A,2)+1)
                  A         A(:,1)]);
clear A 
close('all') 
[L,B]=meshgrid([-180:d:180]*deg,[-90:d:90]*deg);
[X,Y,Z]=sph2cart(L,B,1); 
surf(X,Y,Z,H); 
axis('equal') 
axis([-0.9 0.9 -0.6 0.6 -0.6 0.6]) 
colormap(topocolors(min(min(H)),max(max(H)))) 
shading('interp')
title('') 
xlabel('x') 
ylabel('y') 
zlabel('z') 
caxis([min(min(H)) max(max(H))])
view(135,36); 
hold('on') 
t=[0:d:90]*deg;
plot3(cos(t),sin(t),zeros(size(t)),'k','linewidth',1.5);
plot3(zeros(size(t)),cos(t),sin(t),'k','linewidth',1.5);
plot3(sin(t),zeros(size(t)),cos(t),'k','linewidth',1.5); 
t=[90:d:360]*deg;
plot3(cos(t),sin(t),zeros(size(t)),'k','linewidth',0.25);
plot3(zeros(size(t)),cos(t),sin(t),'k','linewidth',0.25);
plot3(sin(t),zeros(size(t)),cos(t),'k','linewidth',0.25); 
hold('off')
text(1,0,0,'^{ }90^\circ','EraseMode','none','FontName','TimesNewRoman','FontSize',40,'HorizontalAlignment','left','VerticalAlignment','bottom');
text(0,1,0,'90^{\circ }','EraseMode','none','FontName','TimesNewRoman','FontSize',40,'HorizontalAlignment','right','VerticalAlignment','bottom');
text(0,0,1,'90^{\circ  }','EraseMode','none','FontName','TimesNewRoman','FontSize',40,'HorizontalAlignment','center','VerticalAlignment','top');
axis('off') 
print('-deps','Kugeldreieck3R')

% Hilfsfunktionen zur Farbgestaltung

function C=topocolors(a,b)
% schwarz-weiss
q=0.3;
C=[q*gray(-a)+(1-q)*ones(-a,3)
   q*gray(b)+(1-q)*ones(b,3)];
% % Farbe
% C=[topomaptrans(1:36,1:-a)
%   topomaptrans(37:64,1:b)];
% % aufhellen
% a=0.3;
% C=a*C+(1-a)*ones(size(C));

function T=topomaptrans(I,J)
if isempty(J)
  T=[];
else
  load('topo','topomap1')
  K=polyval( polyfit(J([1 end]),I([1 end]),1) , J);
  T=[topomap1(I(1),:)
     interp1(I,topomap1(I,:),K(2:end-1))
     topomap1(I(end),:)];
end
