function Sat

% http://geometrie.hs-nb.de/MATLAB-Programme/Sat.m   Bearbeitungsstand: 23.2.2005
% (C) Martin Nitschke, nitschke@hs-nb.de

% Ausserdem bentigt: Terrainbase 5-Minute Global Digital Elevation Model (tbase.bin)
%                     des National Geophysical Data Center (NGDC)
%                     http://www.ngdc.noaa.gov/mgg/gravity/1999/data/global/tbase/

close('all')
r=6371;
R=35800;
deg=pi/180;
lamS=66*deg; SName='{\itS}'; % (Intelsat 704)';
% lamS=64*deg; SName='{\itS} (Intelsat 906)';
% lamS=19.2*deg; SName='{\itS} (Astra)';
dnn={'linewidth' 0.5};
dck={'linewidth' 2.0};
lamSStr=strrep(sprintf('%.0f^\\circ',lamS/deg),'.',',');
lamA=12*deg; phiA=51*deg; % bei Leipzig, Jena, Gera
[xA,yA,zA]=sph2cart(lamA,phiA,r);
A=[xA;yA;zA];
[xS,yS,zS]=sph2cart(lamS,0,R+r);
S=[xS;yS;zS];
[xSr,ySr,zSr]=sph2cart(lamS,0,r);
Sr=[xSr;ySr;zSr];
Globus(r);
hold('on')
Kreisbogen(Kreis([0 0 0],[r 0 0],[0 r 0]),0,2*pi,'k',dnn{:}); % Aq
Kreisbogen(Kreis([0 0 0],[r 0 0],[0 0 r]),0,2*pi,'k',dnn{:}); % Gr
Kreisbogen(Kreis([0 0 0],[r+0.35*R 0 0],[0 r+R 0]),0,lamS,'k',dnn{:});
Schrift([(0.35*R+r)*cos(lamS/2),(0.35*R+r)*sin(lamS/2),0],lamSStr,'VerticalAlignment','top')
Strecke([r 0 0],[r+0.35*R 0 0],'k',dnn{:});
Strecke(S,Sr,'k',dnn{:});
Schrift(S,SName,'HorizontalAlignment','left','VerticalAlignment','middle')
axis('equal')
grid('on')
view(122,22);
axis([0 2.0e4 0 3.5e4 -r 1.44*r])
V=view;
rtg=V*[R;0;0;1];
Schrift([r,0,0],'Greenwich  ','rotation',180+atan2(rtg(2),rtg(1))/deg,...
  'HorizontalAlignment','right','VerticalAlignment','top')
rtg=V*[S-Sr;1];
Schrift([(R/2+r)*cos(lamS),(R/2+r)*sin(lamS),0],sprintf('  %.0f km',R),'rotation',atan2(rtg(2),rtg(1))/deg,...
  'HorizontalAlignment','center','VerticalAlignment','top')
rtg=V*[S-A;1];
Schrift((A+S)/2,'\bf\itv','rotation',atan2(rtg(2),rtg(1))/deg,...
  'HorizontalAlignment','center','VerticalAlignment','bottom')
Strecke([1.5*r+0.4*R,0,0],[r/2,0,0],'k');
% Strecke([0 r 0],[0 1.5*r+R 0],'k');
% Strecke([0,0,r],[0,0,1.5*r],'k');
xTck=[0:0.5:2]*1e4;
set(gca,'xtick',xTck);
set(gca,'xticklabel','');
rtg=view*[max(ylim)-min(ylim);0;0;1];
for k=1:length(xTck)
  Schrift([xTck(k);max(yLim);min(zLim)],sprintf(' %0.f',xTck(k)),'rotation',90+atan2(rtg(2),rtg(1))/deg,...
    'HorizontalAlignment','left','VerticalAlignment','middle');
end
yTck=[0:0.5:3.5]*1e4;
set(gca,'ytick',yTck);
set(gca,'yticklabel','');
rtg=view*[max(xlim)-min(xlim);0;0;1];
for k=1:length(yTck)
  Schrift([max(xLim);yTck(k);min(zLim)],sprintf('%0.f   ',yTck(k)),'rotation',180+atan2(rtg(2),rtg(1))/deg,...
    'HorizontalAlignment','right','VerticalAlignment','middle');
end
zTck=[-r 0 r];
set(gca,'ztick',zTck);
set(gca,'zticklabel','');
for k=1:length(zTck)
  Schrift([max(xLim);min(yLim);zTck(k)],sprintf('%0.f ',zTck(k)),...
    'HorizontalAlignment','right','VerticalAlignment','bottom');
end
xlabel('         \itx','fontname','Times New Roman','fontsize',24);
ylabel('\ity    ','fontname','Times New Roman','fontsize',24);
zlabel('\itz','fontname','Times New Roman','fontsize',24);
Schrift(A,'\itA',...
    'HorizontalAlignment','center','VerticalAlignment','top','EraseMode','xor');
% Schrift((A+S)/2,'|{\itAS}|',...
%     'HorizontalAlignment','right','VerticalAlignment','bottom');
Pfeil(A,S-A,2000,30*deg,'k');
Zenit=[xA;yA;zA]/r;
Pfeil(A,r*Zenit,2000,30*deg,'k');
Schrift(A+r*Zenit,'\it{\bfe}_{Z }','HorizontalAlignment','right','VerticalAlignment','middle');
v0=(S-A)/norm(S-A);
El=pi/2-acos(Zenit'*v0);
kEl=Kreisbogen(Kreis(A,1.6*r*Zenit,1.6*r*v0),0,pi/2-El,':k',dck{:});
Strecke(A+r*Zenit,A+2*r*Zenit,'k',dnn{:});
Ost=cross([0;0;1],Zenit);
Ost=Ost/norm(Ost);
Pfeil(A,r*Ost,2000,30*deg,'k');
Schrift(A+r*Ost,'_{ }\it{\bfe}_O',...
    'HorizontalAlignment','left','VerticalAlignment','middle');
% Pfeil(A,-r*Ost,2000,30*deg,'k');
% Schrift(A-r*Ost,'\it{\bfe}_W',...
%     'HorizontalAlignment','right','VerticalAlignment','middle');
Nord=cross(Zenit,Ost);
Pfeil(A,r*Nord,2000,30*deg,'k');
Schrift(A+r*Nord,'\it{\bfe}_N',...
    'HorizontalAlignment','left','VerticalAlignment','bottom');
% Pfeil(A,-r*Nord,2000,30*deg,'k');
% Schrift(A-r*Nord,'\it{\bfe}_S',...
%     'HorizontalAlignment','right','VerticalAlignment','top');
vT=(S-A)-Zenit*Zenit'*(S-A)
Az=acos(Nord'*vT/norm(vT));
kAz=Kreisbogen(Kreis(A,r*Nord,r*vT/norm(vT)),0,Az,'--k',dck{:});
Pfeil(A,r*vT/norm(vT),2000,30*deg,'k');
Schrift(A+r*vT/norm(vT),'{\it\bfw}^{o}',...
    'HorizontalAlignment','center','VerticalAlignment','middle');
set(legend([kEl kAz],'Zenitdistanz','Azimut',1),'fontname','Times New Roman','fontsize',24);
print('-deps','Sat')
[Az El]/deg

function Schrift(P,str,varargin)
text(P(1),P(2),P(3),str,'fontname','Times New Roman','fontsize',24,varargin{:});

function Globus(r)
deg=pi/180;

% Datengitter  1/12 
% Quelle: http://www.ngdc.noaa.gov/mgg/gravity/1999/data/global/tbase/

id=fopen('tbase.bin','r'); 
A=fread(id,[4320 2160],'int16=>int16')';
fclose(id);
A=A(end:-1:1,:);
hS=2810;                   % Hhe Sdpol
n=6;
d=n/12;                    % Vergrberung des Gitters auf n/12
A=A(n:n:end,1:n:end);
H=double([repmat(hS,1,size(A,2)+1)
                  A         A(:,1)]);
clear A
lam=[-180:d:180]*deg;
phi=[-90:d:90]*deg;
[Lam,Phi]=meshgrid(lam,phi);
[X,Y,Z]=sph2cart(Lam,Phi,r);
surf(X,Y,Z,H);
axis('equal');
colormap(topocolors(min(min(H)),max(max(H))));
shading('interp');
caxis([min(min(H)) max(max(H))]);
rotate3d('on')

% Hilfsfunktionen zur Farbgestaltung

function C=topocolors(a,b)
% schwarz-weiss
q=0.3;
C=[q*gray(-a)+(1-q)*ones(-a,3)
  q*gray(b)+(1-q)*ones(b,3)];
% % Farbe
% C=[topomaptrans(1:36,1:-a)
%   topomaptrans(37:64,1:b)];
% % aufhellen
% a=0.3;
% C=a*C+(1-a)*ones(size(C));

function T=topomaptrans(I,J)
if isempty(J)
  T=[];
else
  load('topo','topomap1')
  K=polyval( polyfit(J([1 end]),I([1 end]),1) , J);
  T=[topomap1(I(1),:)
    interp1(I,topomap1(I,:),K(2:end-1))
    topomap1(I(end),:)];
end

function w=Vek3d(v)
w=v(:);
if length(w)==2
  w=[w;0]
end

function Pfeil(P,v,L,lambda,varargin);
plot3(P(1)+[0 v(1)],P(2)+[0 v(2)],P(3)+[0 v(3)],varargin{:});
P=P+v;
deg=pi/180;
if nargin<=2
  L=1;
end
if nargin<=3
  lambda=7.5*deg;
end
v=L*v./repmat(sqrt(dot(v,v)),size(P,1),1);
Q=P-v;
t=[0:6:360]*deg;
for k=1:size(P,2)
  N=tan(lambda/2)*null(v(:,k)');
  for w=2:length(t)
    plot3(...
      [P(1,k) Q(1,k)+cos(t(w))*L(:,k)*N(1,1)+sin(t(w))*L(:,k)*N(1,2) Q(1,k)+cos(t(w-1))*L(:,k)*N(1,1)+sin(t(w-1))*L(:,k)*N(1,2) P(1,k)],...
      [P(2,k) Q(2,k)+cos(t(w))*L(:,k)*N(2,1)+sin(t(w))*L(:,k)*N(2,2) Q(2,k)+cos(t(w-1))*L(:,k)*N(2,1)+sin(t(w-1))*L(:,k)*N(2,2) P(2,k)],...
      [P(3,k) Q(3,k)+cos(t(w))*L(:,k)*N(3,1)+sin(t(w))*L(:,k)*N(3,2) Q(3,k)+cos(t(w-1))*L(:,k)*N(3,1)+sin(t(w-1))*L(:,k)*N(3,2) P(3,k)],...
      varargin{:});
  end
end

function K=Kreis(M,v1,v2)
v1=Vek3d(v1);
v2=Vek3d(v2);
n=cross(v1,v2);
n=n/norm(n);
v2=cross(n,v1);
K=struct('M',Vek3d(M),'v1',v1,'v2',norm(v1)*v2/norm(v2),'n',n);

function h=Strecke(A,B,varargin);
A=Vek3d(A);
B=Vek3d(B);
h=plot3([A(1) B(1)],[A(2) B(2)],[A(3) B(3)],varargin{:});

function h=Kreisbogen(K,t0,t1,varargin)
deg=pi/180;
t=linspace(t0,t1,10*(1+round((t1-t0)/deg)));
co=cos(t);
si=sin(t);
h=plot3(K.M(1)+co*K.v1(1)+si*K.v2(1),K.M(2)+co*K.v1(2)+si*K.v2(2),K.M(3)+co*K.v1(3)+si*K.v2(3),varargin{:});
